# Steps Mono

This font was created for the french magazine étapes: to demonstrate a collaborative design on the same font.

[Download](https://github.com/raphaelbastide/steps-mono/archive/master.zip) sources and font files.

## Designers

- Raphaël Bastide [@raphaelbastide](https://twitter.com/raphaelbastide)
- Jean-Baptiste Morizot [@jbmorizot](https://twitter.com/jb_morizot)

## Contribute

Contribution can be accepted by pull request only.

## Specimen

![Specimen Steps Mono Regular and Thin](https://rawgithub.com/raphaelbastide/steps-mono/master/documentation/images/specimen.svg)

### Steps Mono Regular

![Specimen Steps Mono Regular](https://raw.githubusercontent.com/raphaelbastide/steps-mono/master/documentation/images/Demo-Regular-v0.1-specimen-001.png)

### Steps Mono Thin

![Specimen Steps Mono Thin](https://raw.githubusercontent.com/raphaelbastide/steps-mono/master/documentation/images/Demo-Thin-v0.3-specimen-001.png)

## License

This Font Software is licensed under the SIL Open Font License, Version 1.1.
This license is copied below, and is also available with a FAQ at
<http://scripts.sil.org/OFL>

## Repository Layout

This font repository follows the Unified Font Repository v2.0,
a standard way to organize font project source files. Learn more at
<https://github.com/raphaelbastide/Unified-Font-Repository>
